@@ -23,10 +23,7 @@ has cache_size   => ( is => 'ro', isa => Int,  default => 20_000 );
 has foreign_keys => ( is => 'ro', isa => Bool, default => 1 );
 
 # H
-around h_connect => sub {
-    my $orig = shift;
-    my $self = shift;
-
+around h_connect => sub ( $orig, $self ) {
     my $h = $self->$orig;
 
     $h->do('PRAGMA encoding = "UTF-8"');
@@ -42,9 +39,7 @@ around h_connect => sub {
 };
 
 # DBD
-sub _build__connection {
-    my $self = shift;
-
+sub _build__connection ($self) {
     my $attr = P->hash->merge(
         $self->_default_attr,
         {   sqlite_open_flags => $self->mode eq 'R' ? DBD::SQLite::OPEN_READONLY : $self->mode eq 'RW' ? DBD::SQLite::OPEN_READWRITE : DBD::SQLite::OPEN_READWRITE | DBD::SQLite::OPEN_CREATE,
@@ -75,9 +70,7 @@ sub _build__connection {
     return [ qq[dbi:SQLite:dbname=$dbfile], q[], q[], $attr ];
 }
 
-sub version {
-    my $self = shift;
-
+sub version ($self) {
     return $self->h->{sqlite_version};
 }
 
